@@ -31,7 +31,7 @@ BuildPackage <- function() {
   cmd <- append(cmd, paste(cs, "RMDIR /S /Q", path.chk))
   cmd <- append(cmd, paste(cs, "RMDIR /S /Q", path.git))
   cmd <- append(cmd, paste(cs, path.cmd, "build", path.tmp, "--resave-data"))
-  cmd <- append(cmd, paste(cs, path.cmd, "check", path.tar))
+  cmd <- append(cmd, paste(cs, path.cmd, "check --as-cran", path.tar))
   cmd <- append(cmd, paste(cs, path.cmd, "INSTALL --build", path.tar))
   cmd <- append(cmd, paste(cs, "RMDIR /S /Q", path.tmp))
   cmd <- append(cmd, paste(cs, "MOVE /Y", file.zip, path.pkg))
