@@ -17,26 +17,27 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
   ## Main program
 
   # Initialize file filters
-  all.filters <- list(bmp   = "Windows Bitmap Files",
-                      bz2   = "Compressed Text Files",
+  all.filters <- list(bmp   = "Windows Bitmap",
+                      bz2   = "Compressed Text",
                       csv   = "Text Files",
-                      eps   = "Encapsulated Postscript Files",
-                      gz    = "Compressed Text Files",
-                      pdf   = "PDF Files",
-                      ply   = "Polygon Files",
-                      png   = "PNG Files",
-                      jpg   = "Jpeg Files",
-                      jpeg  = "Jpeg Files",
-                      ps    = "Postscript Files",
-                      Rda   = "R Data Files",
-                      rda   = "R Data Files",
-                      RData = "RSurvey Project Files",
-                      shp   = "ESRI Shapefiles",
-                      tab   = "Text Files",
-                      tif   = "TIFF Files",
-                      tiff  = "TIFF Files",
-                      tsv   = "Text Files",
-                      txt   = "Text Files"
+                      eps   = "Encapsulated Postscript",
+                      gz    = "Compressed Text",
+                      pdf   = "PDF",
+                      ply   = "Polygon",
+                      png   = "PNG",
+                      jpg   = "Jpeg",
+                      jpeg  = "Jpeg",
+                      ps    = "Postscript",
+                      Rda   = "R Data",
+                      rda   = "R Data",
+                      RData = "RSurvey Project",
+                      shp   = "ESRI Shapefile",
+                      tab   = "Text",
+                      tif   = "TIFF",
+                      tiff  = "TIFF",
+                      tsv   = "Text",
+                      txt   = "Text",
+                      xlsx  = "Open XML Spreadsheet"
                   )
 
   # Process connection and return
@@ -112,7 +113,7 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
   if (n > 1)
     f <- list()
 
-  for (i in seq(along=ans)) {
+  for (i in seq_along(ans)) {
     val <- ans[i]
     ext <- GetFileExt(val)
     attr(val, "directory") <- dirname(val)
