@@ -1,6 +1,6 @@
 # A GUI for specifying polygon limits.
 
-SetPolygonLimits <- function(poly.names=NULL, data.poly=NULL, crop.poly=NULL,
+SetPolygonLimits <- function(poly.names=NULL, poly.data=NULL, poly.crop=NULL,
                              parent=NULL) {
 
   ## Additional functions (subroutines)
@@ -13,17 +13,17 @@ SetPolygonLimits <- function(poly.names=NULL, data.poly=NULL, crop.poly=NULL,
     box2 <- as.character(tclvalue(crop.var))
     if(box2 == "")
       box2 <- NULL
-    rtn <<- list(data.poly=box1, crop.poly=box2)
+    rtn <<- list(poly.data=box1, poly.crop=box2)
     tclvalue(tt.done.var) <- 1
   }
 
   ## Main program
 
   poly.names <- c("", poly.names)
-  if (!is.null(data.poly) && !data.poly %in% poly.names)
-    data.poly <- NULL
-  if (!is.null(crop.poly) && !crop.poly %in% poly.names)
-    crop.poly <- NULL
+  if (!is.null(poly.data) && !poly.data %in% poly.names)
+    poly.data <- NULL
+  if (!is.null(poly.crop) && !poly.crop %in% poly.names)
+    poly.crop <- NULL
 
   rtn <- NULL
 
@@ -85,16 +85,16 @@ SetPolygonLimits <- function(poly.names=NULL, data.poly=NULL, crop.poly=NULL,
   frame1.box.2.2 <- ttkcombobox(frame1, state="readonly",
                                 textvariable=crop.var, values=vals)
 
-  if (!is.null(data.poly))
-    tcl(frame1.box.1.2, "current", match(data.poly, poly.names) - 1)
+  if (!is.null(poly.data))
+    tcl(frame1.box.1.2, "current", match(poly.data, poly.names) - 1)
 
-  if (!is.null(crop.poly))
-    tcl(frame1.box.2.2, "current", match(crop.poly, poly.names) - 1)
+  if (!is.null(poly.crop))
+    tcl(frame1.box.2.2, "current", match(poly.crop, poly.names) - 1)
 
   tkgrid(frame1.lab.1.1, frame1.box.1.2, pady=c(20, 10))
   tkgrid(frame1.lab.2.1, frame1.box.2.2, pady=c(0, 10))
 
-  tkgrid.configure(frame1.lab.1.1, frame1.lab.2.1, sticky="w")
+  tkgrid.configure(frame1.lab.1.1, frame1.lab.2.1, padx=c(0, 4), sticky="w")
   tkgrid.configure(frame1.box.1.2, frame1.box.2.2, sticky="we")
 
   tkgrid.columnconfigure(frame1, 1, weight=1, minsize=25)
